DefaultCrossmintCredentialsClient class final
- Implemented types
Constructors
- DefaultCrossmintCredentialsClient({required CredentialsApiService service})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
decryptCredential(
CrossmintCredentialDecryptRequest request) → Future< CrossmintDecryptedCredential> -
override
-
getCredential(
CrossmintCredentialQuery query) → Future< CrossmintCredentialRecord> -
override
-
getWalletAuthChallenge(
String address) → Future< CrossmintCredentialWalletAuthChallenge> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited